@@ -58,13 +58,8 @@ as that of the covered work.  */
 
 /* `gettext (FOO)' is long to write, so we use `_(FOO)'.  If NLS is
    unavailable, _(STRING) simply returns STRING.  */
-#if ENABLE_NLS
-#	include <libintl.h>
-#	define _(STRING) gettext(STRING)
-#else
-#	define _(STRING) STRING
-#	define ngettext(STRING1,STRING2,N) STRING2
-#endif
+#include "gettext.h"
+#define _(STRING) gettext(STRING)
 
 /* A pseudo function call that serves as a marker for the automated
    extraction of messages, but does not call gettext().  The run-time
